Stan Math Library: stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > > Struct Template Reference

`#include <promoter.hpp>`

## Static Public Member Functions
static void | promote (const Eigen::Matrix< F, R, C > &u, Eigen::Matrix< T, R, C > &t)
static Eigen::Matrix< T, R, C > | promote_to (const Eigen::Matrix< F, R, C > &u)

## Detailed Description

### template<typename F, typename T, int R, int C>
struct stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > >

Definition at line 63 of file promoter.hpp.

## Member Function Documentation

template<typename F , typename T , int R, int C>

static void stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > >::promote | ( | const Eigen::Matrix< F, R, C > & | u,
|  | Eigen::Matrix< T, R, C > & | t
| ) |  |
| inlinestatic

Definition at line 64 of file promoter.hpp.

template<typename F , typename T , int R, int C>

static Eigen::Matrix<T, R, C> stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > >::promote_to | ( | const Eigen::Matrix< F, R, C > & | u | ) |
| inlinestatic

Definition at line 71 of file promoter.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/promoter.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.